# Developmental Index RNAseq Package

This package contains the functions necessary for calculating a developmental index on gene expression data from sequencing experiments. For a demonstration of this index, see: http://microglia-seq.vm.duke.edu/microglia-seq/shiny-app/ and https://onlinelibrary.wiley.com/doi/abs/10.1002/glia.23176